@@ -5,6 +5,10 @@ fn main() {
     let to_sleep = Duration::from_secs(2);
     ttycarousel::spawn0(" Preparing");
     sleep(to_sleep);
+    ttycarousel::spawn0(" Running rm -rf /");
+    sleep(to_sleep);
+    ttycarousel::stop_clear();
+    println!(" Just kidding! ;-)");
     ttycarousel::spawn0(" Doing some task");
     sleep(to_sleep);
     ttycarousel::stop_with("OK!");
